@@ -185,7 +185,7 @@ class BaseGrader(object):
         }
 
         if hasattr(self, "diff_path"):
-            feedback_dict["diff"] = self.diff_path
+            feedback_dict["image"] = self.diff_path
 
         return feedback_dict
 
@@ -281,9 +281,7 @@ class PythonGrader(BaseGrader):
         else:
             return
 
-    def grade_dict(
-        self, tolerance=0.0, check_hp_keys_only=False, return_bool=False
-    ):
+    def grade_dict(self, tolerance=0.0, return_bool=False):
         """Evaluate student's submitted dict.
 
         Evaluate whether ``submission`` dict matches ``answer``. Depending on parameter
@@ -300,11 +298,6 @@ class PythonGrader(BaseGrader):
             other (relative to the larger absolute value of the two). Uses
             `math.isclose() <https://docs.python.org/3/library/math.html#math.isclose>`_.
 
-        check_hp_keys_only : bool, default=False
-            When answer values don't match answer, only consider incorrect those keys
-            containing ``__``. For use when comparing dictionaries generated from
-            SklearnGrader.
-
         return_bool : bool, default=False
             Whether to return ``self.passed`` once grading is complete. You'll need this if
             you want to design your own grading workflow beyond the default.
@@ -386,15 +379,12 @@ class PythonGrader(BaseGrader):
 
             # For non-numerical values
             if not sub_is_num and sub != ans:
+                print("non-numerical values")
+                print(k)
                 self.update_comment(key_val_comment)
                 self.passed = False
                 break_flag = True
 
-            # For dicts from SklearnGrader get_params
-            if check_hp_keys_only and ("__" not in k):
-                break_flag = False
-                self.passed = True
-
             if break_flag:
                 break
 
@@ -704,6 +694,7 @@ class SklearnGrader(BaseGrader):
         self,
         match_steps=False,
         match_hyperparameters=False,
+        prune_hyperparameters=False,
         match_fitted=True,
         tolerance=0.0,
         return_bool=False,
@@ -719,6 +710,12 @@ class SklearnGrader(BaseGrader):
         match_hyperparameters : bool, default=False
             Whether to consider the hyper parameter values when evaluating submission.
 
+        prune_hyperparameters : bool, default=False
+            When you pull hyperparameters out a a model, it can be a seriously messy
+            dictionary, especially if there's some sort of encoder mapping. So when you
+            set ``match_hyperparameters`` to ``True``, save yourself a headache and set
+            this to ``True``, too.
+
         match_fitted : bool, default=True
             Whether to consider if the submission has or has not been fitted to
             training data.
@@ -846,11 +843,22 @@ class SklearnGrader(BaseGrader):
         if match_hyperparameters:
             sub_params = self.submission.get_params()
             ans_params = self.answer.get_params()
+
+            if prune_hyperparameters:
+                sub_params = {
+                    k: v
+                    for k, v in sub_params.items()
+                    if isinstance(v, (str, bool, float, int))
+                }
+                ans_params = {
+                    k: v
+                    for k, v in ans_params.items()
+                    if isinstance(v, (str, bool, float, int))
+                }
+
             g = PythonGrader(submission=sub_params, answer=ans_params)
             if not g.grade_dict(
                 tolerance=tolerance,
-                # Only need this if model is Pipeline
-                check_hp_keys_only=isinstance(self.submission, Pipeline),
                 return_bool=True,
             ):
                 self.update_comment(g.comment.replace("key", "hyperparameter"))
@@ -1245,7 +1253,7 @@ class PlotGrader(BaseGrader):
             submission = Image.open(submission)
         super().__init__(submission, answer, points)
 
-    def grade_plot_images(
+    def grade_plot_image(
         self,
         threshold=0.0,
         return_diff=True,
@@ -1284,7 +1292,7 @@ class PlotGrader(BaseGrader):
         # Check that submission type is correct
         if not isinstance(self.submission, PngImageFile):
             raise TypeError(
-                "grade_plot_images method can only be used on `PIL.Image` objects, "
+                "grade_plot_image method can only be used on `PIL.Image` objects, "
                 f"not {type(self.submission).__name__} objects."
             )
 
