@@ -53,8 +53,8 @@ def load_csv(
     return df
 
 
-def load_sklearn(filepath, fixture_path=True, **kwargs):
-    """Load pickled model.
+def load_pkl(filepath, fixture_path=True, **kwargs):
+    """Load pickled file.
 
     Wrapper function for ``joblib.load()``. Works with any pickled file.
 
